summaryrefslogtreecommitdiffstats
path: root/kimgio/tiffr.h
diff options
context:
space:
mode:
Diffstat (limited to 'kimgio/tiffr.h')
-rw-r--r--kimgio/tiffr.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kimgio/tiffr.h b/kimgio/tiffr.h
index 18d39f9bb..b7cad3558 100644
--- a/kimgio/tiffr.h
+++ b/kimgio/tiffr.h
@@ -1,5 +1,5 @@
/**
* QImageIO Routines to read/write TIFF images.
* Sirtaj Singh Kang, Oct 1998.
*
* This library is distributed under the conditions of the GNU LGPL.
@@ -13,8 +13,8 @@
class QImageIO;
extern "C" {
-void kimgio_tiff_read( QImageIO *io );
-void kimgio_tiff_write( QImageIO *io );
+void kimgio_tiff_read( TQImageIO *io );
+void kimgio_tiff_write( TQImageIO *io );
}
#endif
@@ -1,5 +1,5 @@
/**
-* QImageIO Routines to read/write TIFF images.
+* TQImageIO Routines to read/write TIFF images.
* Sirtaj Singh Kang, Oct 1998.
*